; ******************************************************************
;
; 			Sprite-Aux-Fer3C header file
;
; ******************************************************************


; ******************************************************************
;
; D6-D7 and A4-A7 are 'global variables' for a sprite
; If you change them, be careful !
; d5   = Reserved
; d6.w = X_Fernando
; d7.w = Y_Fernando
; a4.l = Reserved
; a5.l = Current sprite (at the end of a sprite, a5 must point to the next sprite)
; a6.l = Adress of the variables ! ! ! ! !
; a7.l = Stack
;
; ******************************************************************

x_fernando	EQUR	d6
y_fernando	EQUR	d7
xfer		EQUR	x_fernando
yfer		EQUR	y_fernando
sprite		EQUR	a5
var		EQUR	a6

; ******************************************************************
;
; Start Fernando 3-C
; Entry : a0 -> World Structure :
;		dc.w NumberOfLevels
;		ds.b Packed World
; Return : nothing
; Destroy : all registers
; ******************************************************************

fer3c::Start		EQU	fer3c@0000

; ******************************************************************
;
; 		Global variables of fer3c
; To access at this variable, you can use :
; 	* fer3c::Var17
;	* Or first : lea	fer3c::Variable,a6
;		Then  access like   Screen(a6)
; ******************************************************************

fer3c::Variable		EQU	fer3c@0001



; ******************************************************************
;
; Adress of the current screen
;
; ******************************************************************
fer3c::Screen		EQU	fer3c@0001+0

; ******************************************************************
;
; Adress of the virtual-screen
;
; ******************************************************************
fer3c::VirtualScreenADR	EQU	fer3c@0001+4

; ******************************************************************
;
; Adress of the Level-Graph-File
;
; ******************************************************************
fer3c::LevelADR		EQU	fer3c@0001+14

; ******************************************************************
;
; Adress of the level-Test-File
;
; ******************************************************************
fer3c::LevelTestADR	EQU	fer3c@0001+18

; ******************************************************************
;
; Adress of the sprite-buffer (and the end)
;
; ******************************************************************
fer3c::SpriteADR	EQU	fer3c@0001+22
fer3c::SpriteEndADR	EQU	fer3c@0001+26

; ******************************************************************
;
;	Adress of the GraphFile
;
; ******************************************************************
fer3c::GraphADR		EQU	fer3c@0001+30

; ******************************************************************
;
; Current-Time : usefull to synchronize
;
; ******************************************************************
fer3c::Time		EQU	fer3c@0001+54

; ******************************************************************
;
; X_Scrolling and Y_Scrolling
;
; ******************************************************************
fer3c::Xs		EQU	fer3c@0001+42
fer3c::Ys		EQU	fer3c@0001+44


; ******************************************************************
;
; Adress of Init and Exec Add-On.
;
; ******************************************************************
fer3c::InitAddOnADR	EQU	fer3c@0001+60
fer3c::ExecAddOnADR	EQU	fer3c@0001+56

; ******************************************************************
;
; TURBO MODE : 1, 2 or 4 (or ?)
;
; ******************************************************************
fer3c::Turbo		EQU	fer3c@0001+64

; ******************************************************************
;
; 	Number of players
;
; ******************************************************************
fer3c::Nbr_Player	EQU	fer3c@0001+66

; ******************************************************************
;
; Fernando global data
;
; ******************************************************************
fer3c::Power		EQU	fer3c@0001+74
fer3c::Coins		EQU	fer3c@0001+76
fer3c::Life		EQU	fer3c@0001+72
fer3c::Keys		EQU	fer3c@0001+70
fer3c::Switch		EQU	fer3c@0001+68
fer3c::Plan		EQU	fer3c@0001+69
fer3c::Inv		EQU	fer3c@0001+78
fer3c::Statut		EQU	fer3c@0001+13


; ******************************************************************
;
; Fer3c Save Buffer
;
; ******************************************************************
fer3c::Save		EQU	fer3c@0001+98

; ******************************************************************
;
; Key Board access
;
; ******************************************************************
fer3c::KeyStat		EQU	fer3c@0010

; ******************************************************************
;
; Init one sprite
; Entry : d0.w = Type of the sprite
;	  d1.w = X-Start
;	  d2.w = Y_Start
;	 (d3.w = Adress in the Level-File)
; 	Other entries, look at fer3c.asm (Sprite_Init section)
; Return : The sprite is activated in the sprite-buffer
; Destroy : d0, a0, a1
; 	Some sprites detroy also : d2 and a2
;
; ******************************************************************
fer3c::SpriteInit	EQU	fer3c@0002

; ******************************************************************
;
; Delete the sprite in the sprite-buffer
;
; Entry : a5.l  -> Sprite to destroy.
;	  d0.l	-> Length of the sprite.
; Return : No Return : exit the current sprite and destroy it.
;	You must access like : jmp	fer3c::DestroySprite
; Destroy:	a0,a1,d0
; ******************************************************************

fer3c::DestroySprite	EQU	fer3c@0003

; ******************************************************************
;
; Put one sprite (16 * 16) on the current screen
; Entry :	d0.w = X (between 0 and 4095)
;		d1.w = Y (between 0 and 32*32-1)
;		a0.l = ADR of the sprite (No mask)
;		Set Screen
; Return : Put the sprite at the current screen
; No registers destroyed
; ******************************************************************
fer3c::PutSprite	EQU	fer3c@0004

; ******************************************************************
;
; Is the sprite on a block ? 15 x 15 pixels
; Entry :	d0.w = X
;		d1.w = Y
; Return:	Zero_Flag activated if 'Yes'. (d2=0)
; Destroy : d2 and a0
; ******************************************************************
fer3c::GetTest		EQU	fer3c@0005

; ******************************************************************
;
; Is the sprite tuch Fernando ?
; Entry :	d0.w = X	d6.w = X_Fernando
;		d1.w = Y	d7.w = Y_Fernando
; Return:	Zero_Flag activated  and d2=0 if 'Yes'.
; Destroy:	d2
;
; ******************************************************************
fer3c::TestCollision	EQU	fer3c@0006

; ******************************************************************
;
; Is the sprite outside the screen ?
; Entry :	d0.w = X
;		d1.w = Y
; Return:	Zero_Flag activated and d2=0 if 'Yes'.
; Destroy:	d2
;
; ******************************************************************
fer3c::TestExitScreen	EQU	fer3c@0007

; ******************************************************************
;
; Decrease fernando's power and kill him if power=0.
; Entry :	Nothing
; Return:	Flash_Screen and set the global variables
; Destroy:	d2
;
; ******************************************************************
fer3c::Hurt		EQU	fer3c@0008

; ******************************************************************
;
;	Put the scrolling on the current screen
;	And make the sprite appears in the current screen if the virtual
;	screen must be updated.
; Warning : Use it at your own risk.
; Entry:	LevelADR
;		LevelTestADR
;		Screen
;		VirtualScreenADR
;		GraphADR
;		Xs and Ys
;		XsOld and YsOld
; Return:	Put the Graphs
;		Init sprites
;		Update variables
; Destroy:	All registers
;
; ******************************************************************
fer3c::Scrolling	EQU	fer3c@0009

; ******************************************************************
;
; UpDate ScollVariables : center the scolling on (D0.w, D1.w)
; Entry:	d0 & d1
; Return:	UpDate XsNew and YsNew
; Destroy:	d0 and d1
;
; ******************************************************************
fer3c::UpDateScrollVar	EQU	fer3c@000A

; ******************************************************************
;
;	Draw a fer3c text structure at LCD_MEM.
; Input:	a3 -> Structure
;		d7 = Numbers of entries - 1
; Return:	Clear the screen and put it
; Destroy:	a0, a1, a2, a3, d0, d1, d2 & d7.
; Structure: One entry
; 	Text	dc.w NORMAL		; SetFontSys
;		dc.w 10			; X
;		dc.w 25			; Y
;		dc.l MyText		; *String
;	MyText	dc.b "Hello world",0	; String
;
; ******************************************************************
fer3c::DrawText		EQU	fer3c@000B

; ******************************************************************
;
;	Put 3 Horizontal lines on the screen (Y=d1)
; Input:	d1 = 0 ... 32*32-1
;		Screen
; Return:	Nothing
; Destroy:	Nothing
;
; ******************************************************************
fer3c::PutHor		EQU	fer3c@000C


; ******************************************************************
;
;	Put 3 vertical lines on the screen (X=d0)
; Input:	d1 = 0 ... 4095
;		Screen
; Return:	Nothing
; Destroy:	Nothing
;
; ******************************************************************
fer3c::PutVer		EQU	fer3c@000D

; ******************************************************************
;
;	Exec a level
; Warning : SpriteADR = SpriteEndADR = Adress of a free sprite-buffer.
;	SpriteInit+8 -> End of the free sprite-buffer.
;	a5 -> Compressed Gfx.
;	a1 -> Uncompressed level.
;	a6 -> fer3c::Variable
; ******************************************************************
fer3c::ExecLevel	EQU	fer3c@000E

; ******************************************************************
;
;	Read the option in LevelTestADR
; 	And update data.
; Entry : a5 -> Fernando sprite
;	  d6.w = X_Fernando
;	  d7.w = Y_Fernando
;	  d4.b = keystat
; Return : Update Fernando structure
;
; ******************************************************************
fer3c::ReadOption	EQU	fer3c@000F





; ******************************************************************
;
; Tempory storage macros.
; Don't allocate memory !
; The original macro was made by Patrick Davidson.
;
; ******************************************************************

offset   set      0

rs	MACRO
\1	set	offset		; Set \1 to the current value of offset
offset	set	offset+\2	; New value of offset
	ENDM

rsl	MACRO
\1	set	offset		; Set \1 to the current value of offset
offset	set	offset+4	; New value of offset
	ENDM

rsw	MACRO
\1	set	offset		; Set \1 to the current value of offset
offset	set	offset+2	; New value of offset
	ENDM

rsb	MACRO
\1	set	offset		; Set \1 to the current value of offset
offset	set	offset+1	; New value of offset
	ENDM


rsno	MACRO
\1	set	offset
	ENDM

 rsno	Vitesse
 rs	VirtualScreen,2		; ADR of virtual screen		+0
 rs	TaillePhase,2		; Or Speed of the boss and height of one phase

 rs	Screen,4		; ADR of current screen		+4
 rs	Table,4			; Table of ADR of the 2 screens	+8
 rs	Phase,1			; Must be NULL ( Current screen = 0 or 2 ?)	;12
 rs	Mort,1			; Fernando dies ?		+13

 rs	LevelADR,4		; ADR of the graph-level file	+14
 rs	LevelTestADR,4		; ADR of the test-level file	+18

 rs	SpriteADR,4		; ADR of sprite's buffer	+22
 rs	SpriteADREnd,4		; ADR of the end of the sprite's buffer

 rsno	Phase2ADR		; ADR of Phase 2 (Boss)
 rs	GraphADR,4		; Or ADR of the graph-file	+30

 rsno	Phase1ADR		; ADR of phase 1 (Boss)
 rs	StartX,2		; X_Start			+34
 rs	StartY,2		; Y_Start			+36

 rsno	NbrElement		; Number of the elements of the boss
 rs	XsOld,2			; (X_Scrolling_Old / 32) *32	+38
 rsno	NbrPhase		; Number of the phases of the boss
 rs	YsOld,2			; Or (Y_Scrolling_Old / 32) *32

 rs	Xs,2			; X_Scrolling			+42
 rs	Ys,2			; Y_Scrolling
 rs	XsNew,2			; New X_Scrolling		+46
 rs	YsNew,2			; New Y_Scrolling

 rsb	Frame_Time,23		; Time of one frame (23 * processor clock rate = 1/60 s)	+50
 rs	Link,1			; Link flag
 rs	Clock,2			; Clock (Long)			+52
 rs	Time,2			; Time  (Word)			+54

 rs	ExecAddOnADR,4		; Adress of the exec AddOn/plugin +56
 rs	InitAddOnADR,4		; Adress of the init AddOn/plugin +60

 rsw	Turbo,1			; Turbo (2) or not (1) ?	+64

 rs	NbrJoueur,2		; Number of players - 1		+66

 rsno	Refresh
 rs	BoutON,1		; Switch ON / OFF		+68
 rs	Plan,1			; Current plan = 0 / 1		+69
 rsno	BossLife		; Life of the boss
 rs	Cf,2			; Or number of Keys		+70
 rs	Vi,2			; Lifes				+72
 rs	Bj,2			; Power				+74
 rs	Coins,2			; Coins collected		+76
 rs	v,2			; Invulnerable ?		+78
 rsno	Phase1			; No of phase 1
 rs	ComptBj,2		; Or Max Power			+80
 rsno	Phase2			; No of Phase 2
 rs	ComptVi,2		; Or Max one-up			+82

 rs	Diff,2			; How much power will be dec (Easy Mode) +84
 rs	Diff2,2			; How much time perso = invulnerable (") +86

 rs	str,9			; String for "Convert number to string" +88
 rs	strend,1

 rs	Save,16			; Save	: +98

